#!/bin/bash
gmt gmtset PS_MEDIA letter
gmt gmtset PROJ_LENGTH_UNIT cm
gmt gmtset FORMAT_GEO_MAP D
gmt gmtset PS_PAGE_ORIENTATION portrait
psfile=machaze3.21_dcal.ps
projection=-JM16.0c+
region=-R30.8/35.8/-23.8/-18.6
gmt psbasemap $region $projection -Bxa1.0f0.5 -Bya1.0f0.5 -BWeSn+t'Direct Calibration machaze3.21' -K > $psfile
palette=-Ctables/gmt/cpt/topo.cpt
gmt grdcut tables/gmt/dem/GLOBE/k10g.grd -Gmloc.grd $region -fg
gmt grdgradient mloc.grd -Gmloc_ilum.grd -A340 -Nt
gmt grdimage mloc.grd $palette $projection -Imloc_ilum.grd -O -K >> $psfile
rm mloc.grd mloc_ilum.grd
gmt pscoast $projection $region -Df -Ia,blue -Wblue -O -K >> $psfile
# Raypaths used in direct calibration
gmt psxy -: -R $projection -Wthick,red -O -K << END >> $psfile
   -21.589    32.921
   -21.372    33.197
END
gmt psxy -: -R $projection -Wthick,red -O -K << END >> $psfile
   -21.589    32.921
   -21.372    33.197
END
gmt psxy -: -R $projection -Wthick,red -O -K << END >> $psfile
   -20.824    33.368
   -21.372    33.197
END
gmt psxy -: -R $projection -Wthick,red -O -K << END >> $psfile
   -21.421    33.863
   -21.372    33.197
END
gmt psxy -: -R $projection -Wthick,red -O -K << END >> $psfile
   -21.421    33.863
   -21.372    33.197
END
gmt psxy -: -R $projection -Wthick,red -O -K << END >> $psfile
   -21.421    33.863
   -21.372    33.197
END
gmt psxy -: -R $projection -Wthick,red -O -K << END >> $psfile
   -22.635    33.264
   -21.372    33.197
END
gmt psxy -: -R $projection -Wthick,red -O -K << END >> $psfile
   -22.635    33.264
   -21.372    33.197
END
gmt psxy -: -R $projection -Wthick,red -O -K << END >> $psfile
   -22.635    33.264
   -21.372    33.197
END
gmt psxy -: -R $projection -Wthick,red -O -K << END >> $psfile
   -20.636    34.064
   -21.372    33.197
END
gmt psxy -: -R $projection -Wthick,red -O -K << END >> $psfile
   -20.636    34.064
   -21.372    33.197
END
gmt psxy -: -R $projection -Wthick,red -O -K << END >> $psfile
   -20.636    34.064
   -21.372    33.197
END
gmt psxy -: -R $projection -Wthick,red -O -K << END >> $psfile
   -20.291    33.652
   -21.372    33.197
END
gmt psxy -: -R $projection -Wthick,red -O -K << END >> $psfile
   -20.291    33.652
   -21.372    33.197
END
# Seismic stations used for direct calibration, marked by a triangle
gmt psxy -: -R $projection -St -Wthick,black -Gblack -O -K << END >> $psfile
   -21.589    32.921     0.300
   -20.824    33.368     0.300
   -21.421    33.863     0.300
   -22.635    33.264     0.300
   -20.636    34.064     0.300
   -20.291    33.652     0.300
END
# S-P stations used for direct calibration, marked by an open diamond
gmt psxy -: -R $projection -Sd -Wthick -O -K << END >> $psfile
END
# Cluster events, marked by open black circles
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.403    33.491     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.292    33.293     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.260    33.375     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.263    33.369     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.272    33.400     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.217    33.418     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.385    33.357     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.212    33.453     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.382    33.331     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.355    33.199     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.307    33.277     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.281    33.407     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.176    33.313     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.133    33.383     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.403    33.387     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.375    33.212     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.138    33.293     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.065    33.373     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.349    33.170     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.109    33.450     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.348    33.324     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -20.975    33.356     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.274    33.344     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.072    33.411     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.224    33.368     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.287    33.245     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.221    33.284     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.310    33.301     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.301    33.305     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.017    33.367     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.409    33.432     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.395    33.462     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.374    33.533     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.347    33.374     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.177    33.139     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.424    33.225     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.119    33.335     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.252    33.193     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.275    33.505     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.337    33.544     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -20.974    33.373     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.016    33.407     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -20.948    33.210     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.344    33.448     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.328    33.253     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.436    33.463     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -20.985    33.724     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.316    33.215     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.294    33.510     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -20.988    33.344     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.288    33.455     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.143    33.329     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.340    33.636     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.037    33.354     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -20.999    33.155     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.423    33.171     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.076    33.246     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.165    33.362     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.062    33.290     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.443    33.481     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.317    33.300     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.312    33.396     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.306    33.402     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.385    33.381     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.044    33.212     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.317    33.363     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.532    33.222     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -20.947    33.242     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.342    33.204     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.507    33.402     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.396    33.481     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.438    33.423     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.205    33.324     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.226    33.310     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -20.963    32.964     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -20.994    33.210     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.310    33.390     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.497    33.474     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.042    33.245     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.004    33.262     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.017    33.261     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.198    33.110     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.018    33.271     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.270    33.567     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -20.942    33.243     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.858    33.472     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.265    33.383     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.311    33.401     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.344    33.323     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.223    33.338     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -20.554    33.716     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.213    33.359     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.343    33.322     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.372    33.197     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.259    33.161     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.168    33.443     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.535    33.516     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.529    33.519     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.445    33.441     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.445    33.461     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.423    33.496     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.519    33.485     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.447    33.477     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.489    33.487     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.328    33.567     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.373    33.271     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -20.577    33.760     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.604    33.551     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.537    33.538     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -21.586    33.598     0.200
END
gmt psxy -: -R $projection -Sc -Wthick,black -O -K << END >> $psfile
   -20.625    32.836     0.200
END
# Circle of radius 1 and 2 degrees
gmt psxy -: -R $projection -SE -Wthicker,red -O << END >> $psfile
   -21.207    33.358     0.000   222.000   222.000
   -21.207    33.358     0.000   444.000   444.000
END
